@@ -159,7 +159,13 @@ KSaneWidget::KSaneWidget(QWidget* parent)
     d->m_zFitBtn->setIcon(KIcon("document-preview"));
     d->m_zFitBtn->setToolTip(i18n("Zoom to Fit"));
     connect(d->m_zFitBtn, SIGNAL(clicked()), d->m_previewViewer, SLOT(zoom2Fit()));
-    
+
+    d->m_clearSelBtn = new QToolButton(this);
+    d->m_clearSelBtn->setAutoRaise(true);
+    d->m_clearSelBtn->setIcon(KIcon("edit-clear"));
+    d->m_clearSelBtn->setToolTip(i18n("Clear Selections"));
+    connect(d->m_clearSelBtn, SIGNAL(clicked()), d->m_previewViewer, SLOT(clearSelections()));
+
     d->m_prevBtn = new KPushButton(this);
     d->m_prevBtn->setIcon(KIcon("document-import"));
     d->m_prevBtn->setToolTip(i18n("Scan Preview Image"));
@@ -180,6 +186,7 @@ KSaneWidget::KSaneWidget(QWidget* parent)
     btn_lay->addWidget(d->m_zOutBtn);
     btn_lay->addWidget(d->m_zSelBtn);
     btn_lay->addWidget(d->m_zFitBtn);
+    btn_lay->addWidget(d->m_clearSelBtn);
     btn_lay->addStretch(100);
     btn_lay->addWidget(d->m_prevBtn);
     btn_lay->addWidget(d->m_scanBtn);
@@ -559,7 +566,7 @@ QImage KSaneWidget::toQImageSilent(const QByteArray &data,
             img = QImage(width, height, QImage::Format_RGB32);
             int dI = 0;
             for (int i=0; (i<img.height() && dI<data.size()); i++) {
-                imgLine = (QRgb *)img.scanLine(i);
+                imgLine = reinterpret_cast<QRgb*>(img.scanLine(i));
                 for (j=0; (j<img.width() && dI<data.size()); j++) {
                     imgLine[j] = qRgb(data[dI], data[dI], data[dI]);
                     dI++;
@@ -572,7 +579,7 @@ QImage KSaneWidget::toQImageSilent(const QByteArray &data,
             img = QImage(width, height, QImage::Format_RGB32);
             int dI = 1;
             for (int i=0; (i<img.height() && dI<data.size()); i++) {
-                imgLine = (QRgb *)img.scanLine(i);
+                imgLine = reinterpret_cast<QRgb*>(img.scanLine(i));
                 for (j=0; (j<img.width() && dI<data.size()); j++) {
                     imgLine[j] = qRgb(data[dI], data[dI], data[dI]);
                     dI+=2;
@@ -585,7 +592,7 @@ QImage KSaneWidget::toQImageSilent(const QByteArray &data,
             img = QImage(width, height, QImage::Format_RGB32);
             int dI = 0;
             for (int i=0; (i<img.height() && dI<data.size()); i++) {
-                imgLine = (QRgb *)img.scanLine(i);
+                imgLine = reinterpret_cast<QRgb*>(img.scanLine(i));
                 for (j=0; (j<img.width() && dI<data.size()); j++) {
                     imgLine[j] = qRgb(data[dI], data[dI+1], data[dI+2]);
                     dI+=3;
@@ -598,7 +605,7 @@ QImage KSaneWidget::toQImageSilent(const QByteArray &data,
             img = QImage(width, height, QImage::Format_RGB32);
             int dI = 1;
             for (int i=0; (i<img.height() && dI<data.size()); i++) {
-                imgLine = (QRgb *)img.scanLine(i);
+                imgLine = reinterpret_cast<QRgb*>(img.scanLine(i));
                 for (j=0; (j<img.width() && dI<data.size()); j++) {
                     imgLine[j] = qRgb(data[dI], data[dI+2], data[dI+4]);
                     dI+=6;
